# Array at top level

- [1. Array at top level > items](#autogenerated_heading_2)

**Title:** Array at top level

| Type                      | `array of string`                                                         |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

**Description:** Sometimes there are no properties

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | See below          |
|                      |                    |

| Each item of this array must be | Description |
| ------------------------------- | ----------- |
| [items](#items)                 | A string    |
|                                 |             |

## <a name="autogenerated_heading_2"></a>1. Array at top level > items

| Type                      | `string`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

**Description:** A string

**Example:** 

```json
"Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec ornare mauris ac neque malesuada sagittis. Curabitur vel blandit tortor, at pharetra lorem. Curabitur rhoncus posuere purus ut fringilla. Aenean ac rhoncus enim. Nullam ac consectetur est. Etiam vel congue tellus, ac fermentum lectus. Sed accumsan diam libero, a tincidunt mauris feugiat vitae. Nulla eu bibendum sem, quis finibus libero. Cras metus augue, aliquam at finibus elementum, mollis sed dui. Nulla quis facilisis tortor, ut sollicitudin nunc. Mauris diam nisi, ullamcorper at dignissim in, mollis ut felis. Fusce in libero facilisis, venenatis quam nec, ultrices leo. Cras tempus tristique leo ultrices pulvinar. Duis et leo quis dolor lacinia sagittis. Etiam rhoncus, nisl nec elementum auctor, enim lectus dignissim ipsum, sed consectetur mi magna eget mauris. Donec nunc augue, lacinia id nunc sit amet, accumsan posuere lorem. Sed orci neque, commodo ac nibh sit amet, euismod lacinia purus. Quisque non suscipit nibh, at auctor odio. Quisque facilisis tellus nunc. Integer interdum augue ut elit dictum eleifend. Integer bibendum convallis nisl, ut iaculis ligula vehicula et. Nunc ac diam vel arcu fringilla ullamcorper. "
```

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date